# -*- coding: utf-8 -*-

__title__ = 'camote'
__version__ = '0.1.1'
__author__ = 'Marconi Moreto'


from . import utils
from .queues import Job, CamoteQueue
